import { Component, Injectable, Input, NgModule, Optional, SkipSelf } from '@angular/core';
import { AlertController, IonicModule, IonicPage, LoadingController, ModalController, NavController, NavParams, ViewController } from 'ionic-angular';
import { Headers, Http, HttpModule, RequestOptions, XHRBackend } from '@angular/http';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/throw';
import { CommonModule } from '@angular/common';
import 'rxjs/add/operator/map';
import SHA256 from 'sha256-es';
import { FormBuilder, Validators } from '@angular/forms';
import { Storage } from '@ionic/storage';

/**
 * Generated class for the HeaderComponent component.

See https://angular.io/docs/ts/latest/api/core/index/ComponentMetadata-class.html
for more info on Angular Components.
 */
var TestComponent = (function () {
    function TestComponent() {
        console.log('Hello HeaderComponent Component');
        this.text = 'Hello World';
    }
    return TestComponent;
}());
TestComponent.decorators = [
    { type: Component, args: [{
                selector: 'test',
                template: "<!-- Generated template for the HeaderComponent component --> <ion-header style=\"text-align: center\"> <ion-toolbar class=\"header_container\"> <img src=\"assets/images/bg_logo.png\" style=\"margin-top: 0.5em;\"> </ion-toolbar> </ion-header> "
            },] },
];
/**
 * @nocollapse
 */
TestComponent.ctorParameters = function () { return []; };

var mergeAuthToken = function (options) {
    var /** @type {?} */ uuid = require('uuid4');
    var /** @type {?} */ uuidid = uuid().slice(0, 8).toUpperCase();
    console.log("id is ", uuidid.slice(0, 8).toUpperCase());
    var /** @type {?} */ _headers = new Headers();
    _headers.append('Content-type', 'application/json');
    _headers.append('X-FIS-IdP-Transaction-ID', uuidid);
    _headers.append('X-SunGard-IdP-API-Key', 'SunGard-IdP-Login');
    var /** @type {?} */ _requestOptions = new RequestOptions({ headers: _headers });
    _requestOptions.withCredentials = true;
    // _headers.set('If-Match', '*');
    // let _requestOptions = new RequestOptions({headers: _headers,withCredentials :true}).merge(options);
    return _requestOptions;
};
var CIOAPPApi = (function () {
    /**
     * @param {?} _http
     * @param {?=} baseUrl
     */
    function CIOAPPApi(_http, baseUrl) {
        if (baseUrl === void 0) { baseUrl = 'https://infinitydev.sungard.com/idp-dev/html5'; }
        this._http = _http;
        this.baseUrl = baseUrl;
    }
    /**
     * @return {?}
     */
    CIOAPPApi.prototype.getHeaders = function () {
        return mergeAuthToken().headers;
    };
    /**
     * @param {?} path
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.get = function (path, options) {
        return this._http.get(this.baseUrl + path, mergeAuthToken(options)).map(this._toCIOApiResponse);
    };
    /**
     * @param {?} path
     * @param {?} body
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.post = function (path, body, options) {
        return this._http.post(this.baseUrl + path, body, mergeAuthToken(options)).map(this._toCIOApiResponse);
    };
    /**
     * @param {?} path
     * @param {?} body
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.put = function (path, body, options) {
        return this._http.put(this.baseUrl + path, body, mergeAuthToken(options)).map(this._toCIOApiResponse);
    };
    /**
     * @param {?} path
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.delete = function (path, options) {
        return this._http.delete(this.baseUrl + path, mergeAuthToken(options)).map(this._toCIOApiDeleteResponse);
    };
    /**
     * @param {?} path
     * @param {?} body
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.patch = function (path, body, options) {
        return this._http.patch(this.baseUrl + path, body, mergeAuthToken(options)).map(this._toCIOApiResponse);
    };
    /**
     * @param {?} path
     * @param {?=} options
     * @return {?}
     */
    CIOAPPApi.prototype.head = function (path, options) {
        return this._http.head(this.baseUrl + path, mergeAuthToken(options)).map(this._toCIOApiResponse);
    };
    /**
     * @param {?} response
     * @return {?}
     */
    CIOAPPApi.prototype._toCIOApiResponse = function (response) {
        var /** @type {?} */ _response = {
            data: response.json(),
        };
        if (_response) {
            return _response;
        }
        else {
            throw Observable.throw(_response);
        }
    };
    /**
     * @param {?} response
     * @return {?}
     */
    CIOAPPApi.prototype._toCIOApiDeleteResponse = function (response) {
        var /** @type {?} */ _response = {
            data: response,
        };
        if (_response) {
            return _response;
        }
        else {
            throw Observable.throw(_response);
        }
    };
    return CIOAPPApi;
}());
CIOAPPApi.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
CIOAPPApi.ctorParameters = function () { return [
    { type: Http, },
    null,
]; };

var CIOConstants = {
    loginName: 'User ID',
    captcha: 'Enter the Text in the Image Below',
    remember: 'Remember my User ID',
    password: 'Password',
    otpPin: 'PIN Code',
    otpMessage: 'Please check your One-Time-PIN device to get the PIN code to use below',
    sessionsInstructions: 'You have reached the maximum number of sessions for your user account. A session must be ended for you to proceed. Please close a tab or browser window to continue.',
    sessionStartTime: 'Session Start',
    sessionUUID: 'Unique Identifier',
    'DICT.COMMON_FIELDS.PROCEED_BUTTON': 'Proceed',
    'DICT.COMMON_FIELDS.LOGIN_LOGIN': 'Login',
    'DICT.COMMON.CANCEL': 'Cancel',
    currentStep: '',
    browserFields: '',
    username: '',
    displayOtp: '',
    showcaptcha: '',
    imageURL: '',
    questions: '',
    idpURL: 'https://infinitydev.sungard.com/idp-dev/html5/wizards/authentication',
};

var AuthService = (function () {
    /**
     * @param {?} _api
     * @param {?} http
     */
    function AuthService(_api, http) {
        this._api = _api;
        this.http = http;
    }
    /**
     * @param {?} loginData
     * @return {?}
     */
    AuthService.prototype.loginWithUserName = function (loginData) {
        this.reqBody = {
            step: CIOConstants.currentStep,
            data: {
                keyStroke: '',
                loginName: loginData.loginName ? loginData.loginName : CIOConstants.username,
                browserFootprint: CIOConstants.browserFields,
                remember: loginData.remember,
            }
        };
        if (CIOConstants.currentStep === 'password') {
            this.reqBody.data['desktopRegistered'] = false;
            this.reqBody.data['desktopName'] = false;
            this.reqBody.data['password'] = loginData.password;
        }
        if (CIOConstants.currentStep === 'login') {
            this.reqBody.data['password'] = loginData.password;
        }
        if (CIOConstants.displayOtp === 'true') {
            this.reqBody.data['otpPin'] = loginData.otpPin;
        }
        if (CIOConstants.questions !== 'false') {
            this.reqBody.data['answer'] = loginData.answer;
            this.reqBody.data['questions'] = CIOConstants.questions;
        }
        return this._api.post('/rest/1.0/wizards/authentication/' + CIOConstants.currentStep, this.reqBody).map(function (res) {
            return res;
        });
    };
    /**
     * @param {?} sessionid
     * @return {?}
     */
    AuthService.prototype.postSessions = function (sessionid) {
        this.reqBody = {
            step: CIOConstants.currentStep,
            data: {
                loginName: CIOConstants.username,
                browserFootprint: CIOConstants.browserFields,
                remember: 'true',
                desktopRegistered: 'false',
                desktopName: '',
                uuid: sessionid,
            }
        };
        return this._api.post('/rest/1.0/wizards/authentication/' + CIOConstants.currentStep, this.reqBody).map(function (res) {
            return res;
        });
    };
    /**
     * @return {?}
     */
    AuthService.prototype.loginMetaData = function () {
        var /** @type {?} */ _apiPath;
        _apiPath = '/rest/1.0/wizards/authentication';
        return this._api.get(_apiPath).map(function (res) {
            return res;
        });
    };
    /**
     * @return {?}
     */
    AuthService.prototype.getSessions = function () {
        var /** @type {?} */ _apiPath;
        _apiPath = '/session-manager/active-user/sessions/page/list';
        return this._api.get(_apiPath).map(function (res) {
            return res;
        });
    };
    /**
     * @return {?}
     */
    AuthService.prototype.getCaptchaImage = function () {
        var /** @type {?} */ _apiPath;
        _apiPath = 'https://infinitydev.sungard.com/idp-dev/html5/generate-captcha/' + new Date().getTime() + '.jpg';
        return this.http.get(_apiPath).map(function (res) {
            return res;
        });
    };
    return AuthService;
}());
AuthService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
AuthService.ctorParameters = function () { return [
    { type: CIOAPPApi, },
    { type: Http, },
]; };

var LoginPage = (function () {
    function LoginPage() {
    }
    /**
     * @return {?}
     */
    LoginPage.prototype.ionViewDidLoad = function () {
        console.log('ionViewDidLoad LoginpagePage');
    };
    return LoginPage;
}());
LoginPage.decorators = [
    { type: Component, args: [{
                selector: 'page-loginpage',
                template: "<header> </header> <ion-content scroll=\"false\" class=\"main_container\"> <footer></footer> </ion-content> ",
            },] },
];
/**
 * @nocollapse
 */
LoginPage.ctorParameters = function () { return []; };

/**
 * Generated class for the InitpagePage page.

See http://ionicframework.com/docs/components/#navigation for more info
on Ionic pages and navigation.
 */
var NextPage = (function () {
    function NextPage() {
    }
    /**
     * @param {?} res
     * @return {?}
     */
    NextPage.prototype.getcurrtenstep = function (res) {
        this.userData = res.data.nextStep;
        CIOConstants.currentStep = this.userData.id;
        CIOConstants.username = this.userData.params.loginName ? this.userData.params.loginName : CIOConstants.username;
        CIOConstants.showcaptcha = this.userData.params.showCaptchaField ? this.userData.params.showCaptchaField : CIOConstants.showcaptcha;
        // alert(CIOConstants.showcaptcha);
        CIOConstants.browserFields = SHA256.hash(this.userData.params.browserFields);
        CIOConstants.displayOtp = this.userData.params.displayOtp ? this.userData.params.displayOtp : "false";
        if (this.userData.params.imageUrl) {
            CIOConstants.imageURL = this.userData.params.imageUrl;
        }
        return this._mapNextPage(CIOConstants.currentStep, res);
    };
    /**
     * @param {?} page
     * @param {?} res
     * @return {?}
     */
    NextPage.prototype._mapNextPage = function (page, res) {
        var /** @type {?} */ _nextPage;
        var /** @type {?} */ _value;
        switch (page) {
            case page:
                _nextPage = LoginPage;
                _value = res;
                break;
            default:
                // _nextPage = this._isSignedIn ? HomePage : LoginPage;
                break;
        }
        return _nextPage;
    };
    return NextPage;
}());
NextPage.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NextPage.ctorParameters = function () { return []; };

/**
 * @param {?} xhrBackend
 * @param {?} requestOptions
 * @return {?}
 */
function createCioAppApi(xhrBackend, requestOptions) {
    'use strict';
    var /** @type {?} */ ngHttp = new Http(xhrBackend, requestOptions);
    return new CIOAPPApi(ngHttp, "https://infinitydev.sungard.com/idp-dev/html5");
}
var CoreModule = (function () {
    /**
     * @param {?} parentModule
     */
    function CoreModule(parentModule) {
        if (parentModule) {
            throw new Error('CoreModule is already loaded. Import it in the AppModule only');
        }
    }
    return CoreModule;
}());
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    HttpModule,
                ],
                declarations: [],
                providers: [
                    {
                        provide: CIOAPPApi,
                        useFactory: createCioAppApi,
                        deps: [XHRBackend, RequestOptions],
                    },
                    AuthService,
                    NextPage,
                ],
                exports: [],
            },] },
];
/**
 * @nocollapse
 */
CoreModule.ctorParameters = function () { return [
    { type: CoreModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
]; };

/**
 * Generated class for the ImagesPageComponent component.

See https://angular.io/docs/ts/latest/api/core/index/ComponentMetadata-class.html
for more info on Angular Components.
 */
var ImagesPageComponent = (function () {
    /**
     * @param {?} navCtrl
     * @param {?} _viewCtrl
     * @param {?} navParams
     */
    function ImagesPageComponent(navCtrl, _viewCtrl, navParams) {
        this.navCtrl = navCtrl;
        this._viewCtrl = _viewCtrl;
        this.navParams = navParams;
        this.title = '';
        this.imageArray = [];
        this.title = navParams.get('title');
        this.imageArray = navParams.get('input');
        console.log('Hello ImagesPageComponent Component');
        this.text = 'Hello World';
        alert(this.title);
        alert(this.imageArray);
    }
    /**
     * @return {?}
     */
    ImagesPageComponent.prototype.onSelectedImage = function () {
        if (this.selectedimage) {
            this._viewCtrl.dismiss(this.selectedimage);
        }
    };
    return ImagesPageComponent;
}());
ImagesPageComponent.decorators = [
    { type: Component, args: [{
                selector: 'images-page',
                template: "<ion-header> <ion-navbar color=\"primary\"> <ion-buttons left> <button ion-button navPop icon-only> <ion-icon name=\"ios-arrow-back\"></ion-icon> </button> </ion-buttons> <ion-title>{{title}}</ion-title> </ion-navbar> </ion-header> <ion-content padding margin-bottom> <ion-list *ngIf=\"images\"> <ion-item *ngFor=\"let item of images\"> {{item}} <!--<img ng-src=\"{{item}}\" ng-click=\"onSelectedImage()\"  [(ngModel)]=\"selectedimage\" />--> </ion-item> <ion-row class=\"cio_row_margin_top\"> <ion-col col-7 align-self-center> <ion-label ion-button> Cancel</ion-label> </ion-col> <ion-col col-5 align-self-center class=\"col_text_center\"> <button ion-button> Get More Images </button> </ion-col> </ion-row> </ion-list> </ion-content> "
            },] },
];
/**
 * @nocollapse
 */
ImagesPageComponent.ctorParameters = function () { return [
    { type: NavController, },
    { type: ViewController, },
    { type: NavParams, },
]; };

/**
 * Generated class for the FooterComponent component.

See https://angular.io/docs/ts/latest/api/core/index/ComponentMetadata-class.html
for more info on Angular Components.
 */
var ContentpageComponent = (function () {
    /**
     * @param {?} _formBuilder
     * @param {?} _authService
     * @param {?} _loadingCtrl
     * @param {?} _navCtrl
     * @param {?} _storage
     * @param {?} _nextPage
     * @param {?} _modalCtrl
     */
    function ContentpageComponent(_formBuilder, _authService, _loadingCtrl, _navCtrl, _storage, _nextPage, _modalCtrl) {
        this._formBuilder = _formBuilder;
        this._authService = _authService;
        this._loadingCtrl = _loadingCtrl;
        this._navCtrl = _navCtrl;
        this._storage = _storage;
        this._nextPage = _nextPage;
        this._modalCtrl = _modalCtrl;
        this.localconstants = CIOConstants;
        console.log('Hello contentpage Component ');
        this.view = this.localconstants.currentStep;
    }
    /**
     * @return {?}
     */
    ContentpageComponent.prototype.selectimageOption = function () {
        var /** @type {?} */ modal = this._modalCtrl.create(ImagesPageComponent, {
            title: 'Select an image',
            input: { imagesUrl: this.images },
        });
        modal.onDidDismiss(function (data) {
            if (data) {
            }
        });
        modal.present();
    };
    /**
     * @return {?}
     */
    ContentpageComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.setValidators();
        this._storage.get('loggedinUser').then(function (val) {
            _this.images = val;
            _this.selectimageOption();
        });
    };
    /**
     * @return {?}
     */
    ContentpageComponent.prototype.ionViewDidLoad = function () {
        console.log('ionViewDidLoad LoginpagePage');
    };
    /**
     * @return {?}
     */
    ContentpageComponent.prototype.setValidators = function () {
        if (this.view === 'username') {
            this.loginForm = this._formBuilder.group({
                'loginName': ['', Validators.required],
                'remember': [false],
            });
        }
    };
    /**
     * @return {?}
     */
    ContentpageComponent.prototype.onSubmit = function () {
        this._doLogin(this.loginForm);
    };
    /**
     * @param {?} loginDetails
     * @return {?}
     */
    ContentpageComponent.prototype._doLogin = function (loginDetails) {
        var _this = this;
        this._authService.loginWithUserName(this.loginForm.value).subscribe(function (user) {
            _this._storage.set('loggedinUser', user.data.nextStep.params.loginName);
            _this.localconstants.username = user.data.nextStep.params.loginName;
            _this.localconstants.displayOtp = user.data.nextStep.params.displayOtp;
            _this._navCtrl.setRoot(_this._nextPage.getcurrtenstep(user));
            alert(_this.view);
            _this.setValidators();
            // location.reload();
        }, function (e) {
        });
    };
    return ContentpageComponent;
}());
ContentpageComponent.decorators = [
    { type: Component, args: [{
                selector: 'contentpage',
                template: "<div class=\"inner_container\"> <div class=\"container\"> <div class=\"container_padding\"> <ion-row class=\"cio_row_margin_top\"> <ion-col col-7 align-self-center> <ion-label class=\"cio_trouble_signIn\"> Trouble signing in?</ion-label> </ion-col> <ion-col col-5 align-self-center class=\"col_text_center\"> <button ion-button round type=\"submit\" [ngClass]=\"loginForm.valid ? 'button_enabled': 'button_disabled'\" [disabled]=\"!loginForm.valid\"> PROCEED </button> </ion-col> </ion-row> </div> </div> </div> "
            },] },
];
/**
 * @nocollapse
 */
ContentpageComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: AuthService, },
    { type: LoadingController, },
    { type: NavController, },
    { type: Storage, },
    { type: NextPage, },
    { type: ModalController, },
]; };
ContentpageComponent.propDecorators = {
    'view': [{ type: Input },],
};

/**
 * Generated class for the FbquestionPage page.

See http://ionicframework.com/docs/components/#navigation for more info
on Ionic pages and navigation.
 */
var FbquestionPage = (function () {
    /**
     * @param {?} navCtrl
     * @param {?} navParams
     * @param {?} _authService
     * @param {?} _nextPage
     */
    function FbquestionPage(navCtrl, navParams, _authService, _nextPage) {
        this.navCtrl = navCtrl;
        this.navParams = navParams;
        this._authService = _authService;
        this._nextPage = _nextPage;
    }
    /**
     * @return {?}
     */
    FbquestionPage.prototype.ionViewDidLoad = function () {
        console.log('ionViewDidLoad InitpagePage');
        this.sessionList = {
            "data": [
                {
                    "uuid": "75d6bb0f-75e2-40d1-b4fd-7695c1f48348",
                    "firmId": 137224,
                    "firmName": "html5",
                    "userId": 8468477,
                    "userName": "re, sunitha",
                    "loginName": "SUNITHAREDDY",
                    "loginRole": "Firm Admin",
                    "sessionStartTime": "2017-08-24T08:23:50.750Z",
                    "sessionLength": 60,
                    "terminated": 0
                },
                {
                    "uuid": "b6e53510-f1e6-46ce-8f91-df20a9b93db2",
                    "firmId": 137224,
                    "firmName": "html5",
                    "userId": 8468477,
                    "userName": "re, sunitha",
                    "loginName": "SUNITHAREDDY",
                    "loginRole": "Firm Admin",
                    "sessionStartTime": "2017-08-24T08:31:15.907Z",
                    "sessionLength": 60,
                    "terminated": 0
                }
            ],
            "columns": [
                {
                    "name": "CSSESSION_LOGINNAME",
                    "title": "Login Name",
                    "sortable": true,
                    "hidden": false,
                    "field": "loginName",
                    "filterable": true,
                    "dataType": "string",
                    "uiType": "Text",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_LOGINROLE",
                    "title": "Login Role",
                    "sortable": true,
                    "hidden": false,
                    "field": "loginRole",
                    "filterable": true,
                    "dataType": "string",
                    "uiType": "Text",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_USERNAME",
                    "title": "User Name",
                    "sortable": false,
                    "hidden": false,
                    "field": "userName",
                    "filterable": false,
                    "dataType": "string",
                    "uiType": "Text",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_SESSIONSTARTIME",
                    "title": "Session Start Time",
                    "sortable": false,
                    "hidden": false,
                    "field": "sessionStartTime",
                    "filterable": false,
                    "dataType": "datetime",
                    "uiType": "Timestamp",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_SESSIONLENGTH",
                    "title": "Session Length (Min)",
                    "sortable": false,
                    "hidden": false,
                    "field": "sessionLength",
                    "filterable": false,
                    "dataType": "integer",
                    "uiType": "Integer",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_UUID",
                    "title": "Unique Identifier",
                    "sortable": false,
                    "hidden": false,
                    "field": "uuid",
                    "filterable": false,
                    "dataType": "string",
                    "uiType": "Text",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_CSUSERID",
                    "title": "User ID",
                    "sortable": false,
                    "hidden": true,
                    "field": "userId",
                    "filterable": false,
                    "dataType": "integer",
                    "uiType": "Long",
                    "possibleValues": []
                },
                {
                    "name": "CSSESSION_CSFIRMID",
                    "title": "Firm ID",
                    "sortable": false,
                    "hidden": true,
                    "field": "firmId",
                    "filterable": false,
                    "dataType": "integer",
                    "uiType": "Long",
                    "possibleValues": []
                }
            ],
            "sortOrder": [],
            "pageSizes": [
                10,
                25,
                50,
                100
            ],
            "filter": null,
            "pageSize": 25,
            "total": 2,
            "metaData": null
        };
        this.sessionList = this.sessionList.data;
        // alert(JSON.stringify(this.sessionList));
        this.getUserSessions();
    };
    /**
     * @param {?} e
     * @return {?}
     */
    FbquestionPage.prototype.datachanged = function (e) {
        this.checkedIdx = e;
        console.log(e);
    };
    /**
     * @return {?}
     */
    FbquestionPage.prototype.getUserSessions = function () {
        var _this = this;
        this._authService.getSessions().subscribe(function (res) {
            alert(res);
            _this.sessionList = res.data;
            // this.navCtrl.setRoot(this._nextPage.getcurrtenstep(res));
        }, function (e) {
        });
    };
    /**
     * @return {?}
     */
    FbquestionPage.prototype.sessionLogout = function () {
        var _this = this;
        //  alert(CIOConstants.currentStep);
        this._authService.postSessions(this.checkedIdx).subscribe(function (user) {
            _this.navCtrl.setRoot(_this._nextPage.getcurrtenstep(user));
        }, function (e) {
        });
    };
    return FbquestionPage;
}());
FbquestionPage.decorators = [
    { type: Component, args: [{
                selector: 'page-fbquestion',
                template: "<!-- Generated template for the FbquestionPage page. See http://ionicframework.com/docs/components/#navigation for more info on Ionic pages and navigation. --> <header> </header> <ion-content padding style=\"margin-top:38px\"> <ion-label text-wrap>You have reached the maximum number of sessions for your user account. A session must be ended for you to proceed. Please close a tab or browser window to continue.</ion-label> <ion-list *ngFor=\"let item of sessionList\"> <ion-item-group> <ion-item-divider light> {{item.userName}} </ion-item-divider> <ion-item> <ion-checkbox color=\"dark\" checked=\"false\" (ionChange)=\"datachanged(item.uuid)\"></ion-checkbox> </ion-item> <ion-item text-wrap> <ion-label> uuid : {{item.uuid}} </ion-label> </ion-item> <ion-item text-wrap> <ion-label> userName: {{item.userName}}</ion-label>  </ion-item> <ion-item text-wrap> <ion-label> sessionStartTime: {{item.sessionStartTime}} </ion-label> </ion-item> <ion-item text-wrap> <ion-label> sessionLength: {{item.sessionLength}}</ion-label> </ion-item> </ion-item-group> <ion-row class=\"cio_row_margin_top\"> <ion-col col-5 align-self-center class=\"col_text_center\">  <button ion-button  [ngClass]=\"button_enabled\" (click)=\"sessionLogout()\">Proceed</button> </ion-col> </ion-row> </ion-list> </ion-content> ",
            },] },
];
/**
 * @nocollapse
 */
FbquestionPage.ctorParameters = function () { return [
    { type: NavController, },
    { type: NavParams, },
    { type: AuthService, },
    { type: NextPage, },
]; };

/**
 * Generated class for the FooterComponent component.

See https://angular.io/docs/ts/latest/api/core/index/ComponentMetadata-class.html
for more info on Angular Components.
 */
var FooterComponent = (function () {
    /**
     * @param {?} _formBuilder
     * @param {?} _authService
     * @param {?} _loadingCtrl
     * @param {?} _navCtrl
     * @param {?} _storage
     * @param {?} _alertCtrl
     * @param {?} _nextPage
     */
    function FooterComponent(_formBuilder, _authService, _loadingCtrl, _navCtrl, _storage, _alertCtrl, _nextPage) {
        this._formBuilder = _formBuilder;
        this._authService = _authService;
        this._loadingCtrl = _loadingCtrl;
        this._navCtrl = _navCtrl;
        this._storage = _storage;
        this._alertCtrl = _alertCtrl;
        this._nextPage = _nextPage;
        this.localconstants = CIOConstants;
        console.log('Hello FooterComponent Component');
        this.view = this.localconstants.currentStep;
        // alert(this.view);
    }
    /**
     * @return {?}
     */
    FooterComponent.prototype.ngOnInit = function () {
        // alert(this.localconstants.currentStep);
        this.setValidators();
    };
    /**
     * @return {?}
     */
    FooterComponent.prototype.ionViewDidLoad = function () {
        console.log('ionViewDidLoad LoginpagePage');
    };
    /**
     * @return {?}
     */
    FooterComponent.prototype.setValidators = function () {
        if (this.view === 'username') {
            this.loginForm = this._formBuilder.group({
                'loginName': [''],
                'remember': [false],
                'enteredCapcha': [''],
            });
        }
        else if (this.view === 'password') {
            this.loginForm = this._formBuilder.group({
                'password': [''],
                'otpPin': [''],
                'answer': [''],
            });
            // if (this.view === 'password' && CIOConstants.displayOtp === 'true') {
            //   this.loginForm = this._formBuilder.group({
            //     'password': ['', Validators.required],
            //     'otpPin': ['', Validators.required],
            //   });
            // } else if (this.view === 'password' && CIOConstants.questions !== '') {
            //   this.loginForm = this._formBuilder.group({
            //     'password': ['', Validators.required],
            //     'answer': ['', Validators.required],
            //   });
            // } else {
            //   this.loginForm = this._formBuilder.group({
            //     'password': ['', Validators.required], 
            //   });
            // }
        }
        else if (this.view === 'login') {
            this.loginForm = this._formBuilder.group({
                'loginName': ['', Validators.required],
                'password': ['', Validators.required],
            });
        }
        else {
            this.loginForm = this._formBuilder.group({});
        }
    };
    /**
     * @return {?}
     */
    FooterComponent.prototype.onSubmit = function () {
        this._doLogin(this.loginForm);
    };
    /**
     * @param {?} loginDetails
     * @return {?}
     */
    FooterComponent.prototype._doLogin = function (loginDetails) {
        // alert(loginDetails);
        // alert(JSON.stringify(this.loginForm.value));
        var _this = this;
        this._authService.loginWithUserName(this.loginForm.value).subscribe(function (user) {
            _this._storage.set('loggedinUser', user.data.nextStep);
            if (CIOConstants.showcaptcha) {
                _this.getCaptcha();
            }
            _this.localconstants.questions = user.data.nextStep.params.questions ? user.data.nextStep.params.questions : 'false';
            // this.localconstants.images = user.data.nextStep.params.images ? user.data.nextStep.params.images : 'false';
            if (user.data.nextStep.id === 'antiphishing') {
                _this._navCtrl.push(ContentpageComponent);
            }
            else if (user.data.nextStep.id === 'tooManyActiveSessionPage') {
                _this._nextPage.getcurrtenstep(user);
                _this._navCtrl.push(FbquestionPage);
            }
            else if (user.data.nextStep.id === null) {
                // this._navCtrl.push(HomePage);
            }
            else {
                _this._navCtrl.setRoot(_this._nextPage.getcurrtenstep(user));
            }
            _this.setValidators();
            // location.reload();
        }, function (e) {
            alert(e);
        });
    };
    /**
     * @return {?}
     */
    FooterComponent.prototype.getCaptcha = function () {
        var _this = this;
        this._authService.getCaptchaImage().subscribe(function (res) {
            _this.captchaimage = res;
            alert(res);
            // this.navCtrl.setRoot(this._nextPage.getcurrtenstep(res));
        }, function (e) {
        });
    };
    /**
     * @return {?}
     */
    FooterComponent.prototype.openOTPModal = function () {
        var /** @type {?} */ alert = this._alertCtrl.create({
            title: 'What is the One-Time-PIN?',
            message: "The One-Time-PIN (OTP) is a secondary authentication measure for securely signing into an account from any device. By default, the OTP will be sent to the email address registered to your account; however, if you are unable to access the your email account on the device tap “Trouble signing in” on the sign-in screen. Then select “I cannot access my OTP” from the list todeliver the OTP via text or through one of the supported authenticator apps (Google Authenticator/Microsoft Authenticator).",
            buttons: [{
                    text: 'OK',
                    cssClass: 'buttoncss'
                }]
        });
        alert.present();
    };
    return FooterComponent;
}());
FooterComponent.decorators = [
    { type: Component, args: [{
                selector: 'footer',
                template: "<div class=\"inner_container\"> <div class=\"container\"> <div class=\"container_padding\"> <ion-label class=\"lbl_primary no_margin\" *ngIf=\"view === 'username'\"> SIGN IN </ion-label> <form novalidate [formGroup]=\"loginForm\" (ngSubmit)=\"onSubmit()\"> <ion-item  *ngIf=\"view === 'password' && localconstants.displayOtp === true\" style=\"background-color: #c9e5a5;\"> <ion-icon item-start class=\"help_icon\" name=\"md-information-circle\"></ion-icon> <ion-label  text-wrap>Please check your One-Time-PIN device to get the PIN code to use below</ion-label> </ion-item> <div> <ion-label class=\"lbl_secondary\">User ID </ion-label> <ion-label dark class=\"lbl_secondary color_dark\" *ngIf=\"view === 'password'\"> {{ localconstants.username }} </ion-label> <ion-input *ngIf=\"view === 'username' || view === 'login'\" [ngClass]=\"loginName ? 'form_active': 'form_normal'\" formControlName=\"loginName\" ngDefaultControl required> </ion-input> </div> <div  *ngIf=\"localconstants.showcaptcha === true\"> <ion-label dark class=\"lbl_secondary\"> {{ localconstants.captcha }} </ion-label> <ion-input  [ngClass]=\"enteredCapcha ? 'form_active': 'form_normal'\" formControlName=\"enteredCapcha\" ngDefaultControl required> </ion-input> </div> <div class=\"header_container\" *ngIf=\"localconstants.showcaptcha === true\" > <!--<ion-label class=\"lbl_secondary no_margin\"> Refresh </ion-label>--> <ion-row justify-content-center> <ion-col no-padding class=\"max-width\"> <img src=\"captchaimage\" style=\"margin-top: 0.5em;\">  </ion-col> <ion-col no-padding> <ion-icon class=\"help_icon\" name=\"help-circle\" (click)=\"getCaptcha()\"></ion-icon> </ion-col> </ion-row> </div> <div *ngIf=\"view === 'password' || view === 'login'\"> <ion-label class=\"lbl_secondary\"> Password</ion-label> <ion-input [ngClass]=\"password ? 'form_active': 'form_normal'\" formControlName=\"password\" ngDefaultControl required type=\"password\"> </ion-input> </div> <div *ngIf=\"view === 'password' && localconstants.displayOtp === true\" class=\"margin-top-2\"> <ion-row justify-content-center> <ion-col no-padding class=\"max-width\"> <ion-label class=\"lbl_secondary no_margin\"> One-Time-PIN  </ion-label> </ion-col> <ion-col no-padding> <ion-icon class=\"help_icon\" name=\"help-circle\" (click)=\"openOTPModal()\"></ion-icon> </ion-col> </ion-row> <ion-input [ngClass]=\"otpPin ? 'form_active': 'form_normal'\" formControlName=\"otpPin\" ngDefaultControl required type=\"password\"> </ion-input> </div> <div *ngIf=\"view === 'password' && localconstants.questions !== 'false'\" class=\"margin-top-2\"> <ion-row justify-content-center> <ion-col no-padding class=\"max-width\"> <ion-label class=\"lbl_secondary no_margin\"> {{ localconstants.questions }} </ion-label> </ion-col> </ion-row> <ion-input [ngClass]=\"answer ? 'form_active': 'form_normal'\" formControlName=\"answer\" ngDefaultControl required type=\"password\"> </ion-input> </div> <ion-row *ngIf=\"view === 'username'\"> <ion-item no-lines class=\"padding-0\"> <ion-label class=\"lbl_secondary margin-top-17\">Remember Me</ion-label> <ion-checkbox class=\"isRememberCheck\" formControlName=\"remember\"></ion-checkbox> </ion-item> </ion-row> <ion-row class=\"cio_row_margin_top\"> <ion-col col-7 align-self-center> <ion-label class=\"cio_trouble_signIn\" (click)=\"openOTPModal()\"> Trouble signing in?</ion-label> </ion-col> <ion-col col-5 align-self-center class=\"col_text_center\"> <button ion-button round type=\"submit\" [ngClass]=\"loginForm.valid ? 'button_enabled': 'button_disabled'\" [disabled]=\"!loginForm.valid\"> PROCEED </button> </ion-col> </ion-row> </form> </div> </div> </div> "
            },] },
];
/**
 * @nocollapse
 */
FooterComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: AuthService, },
    { type: LoadingController, },
    { type: NavController, },
    { type: Storage, },
    { type: AlertController, },
    { type: NextPage, },
]; };
FooterComponent.propDecorators = {
    'view': [{ type: Input },],
};

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (undefined && undefined.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/**
 * Generated class for the InitpagePage page.

See http://ionicframework.com/docs/components/#navigation for more info
on Ionic pages and navigation.
 */
var InitPage = (function () {
    /**
     * @param {?} navCtrl
     * @param {?} navParams
     * @param {?} _authService
     * @param {?} _nextPage
     */
    function InitPage(navCtrl, navParams, _authService, _nextPage) {
        this.navCtrl = navCtrl;
        this.navParams = navParams;
        this._authService = _authService;
        this._nextPage = _nextPage;
    }
    /**
     * @return {?}
     */
    InitPage.prototype.ionViewDidLoad = function () {
        console.log('ionViewDidLoad InitpagePage');
        this.getMetaData();
    };
    /**
     * @return {?}
     */
    InitPage.prototype.getMetaData = function () {
        var _this = this;
        this._authService.loginMetaData().subscribe(function (res) {
            _this.navCtrl.setRoot(_this._nextPage.getcurrtenstep(res));
        }, function (e) {
        });
    };
    return InitPage;
}());
InitPage.decorators = [
    { type: Component, args: [{
                selector: 'page-initpage',
                template: "<!--<header> </header>--> <test></test> <ion-content scroll=\"false\" class=\"main_container\"> <footer></footer> </ion-content> ",
            },] },
];
/**
 * @nocollapse
 */
InitPage.ctorParameters = function () { return [
    { type: NavController, },
    { type: NavParams, },
    { type: AuthService, },
    { type: NextPage, },
]; };
InitPage = __decorate([
    IonicPage(),
    __metadata("design:paramtypes", [NavController,
        NavParams,
        AuthService,
        NextPage])
], InitPage);

var SampleService = (function () {
    function SampleService() {
    }
    return SampleService;
}());
SampleService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SampleService.ctorParameters = function () { return []; };

var SampleModule = (function () {
    function SampleModule() {
    }
    /**
     * @return {?}
     */
    SampleModule.forRoot = function () {
        return {
            ngModule: SampleModule,
            providers: [CoreModule]
        };
    };
    return SampleModule;
}());
SampleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    IonicModule
                ],
                declarations: [
                    LoginPage,
                    TestComponent,
                    InitPage,
                    FooterComponent,
                    ContentpageComponent,
                    FbquestionPage,
                ],
                exports: [
                    LoginPage,
                    InitPage,
                    FooterComponent,
                    ContentpageComponent,
                    FbquestionPage,
                    TestComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
SampleModule.ctorParameters = function () { return []; };

export { SampleModule, FbquestionPage, LoginPage, InitPage, TestComponent, ContentpageComponent, FooterComponent, SampleService, createCioAppApi, CoreModule };
